<?php
00002 /* Copyright (C) 2003   Rodolphe Quiedeville <rodolphe@quiedeville.org>
00003  * Copyright (C) 2004-2012  Laurent Destailleur  <eldy@users.sourceforge.net>
00004  * Copyright (C) 2005-2012  Regis Houssin        <regis.houssin@capnetworks.com>
00005  * Copyright (C) 2012   Juanjo Menent        <jmenent@2byte.es>
00006  * Copyright (C) 2013       Florian Henry       <florian.henry@open-concept.pro>
00007  *
00008  * This program is free software; you can redistribute it and/or modify
00009  * it under the terms of the GNU General Public License as published by
00010  * the Free Software Foundation; either version 3 of the License, or
00011  * (at your option) any later version.
00012  *
00013  * This program is distributed in the hope that it will be useful,
00014  * but WITHOUT ANY WARRANTY; without even the implied warranty of
00015  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
00016  * GNU General Public License for more details.
00017  *
00018  * You should have received a copy of the GNU General Public License
00019  * along with this program. If not, see <http://www.gnu.org/licenses/>.
00020  */

00027 require_once '../../main.inc.php';
00028 require_once DOL_DOCUMENT_ROOT.'/core/lib/trip.lib.php';
00029 require_once DOL_DOCUMENT_ROOT.'/compta/deplacement/class/deplacement.class.php';
00030 require_once DOL_DOCUMENT_ROOT.'/core/class/html.formfile.class.php';
00031 if (! empty($conf->projet->enabled))
00032 
00033     require_once DOL_DOCUMENT_ROOT.'/projet/class/project.class.php';
00034 
00035 
00036 $langs->load("trips");
00037 
00038 
00039 // Security check
00040 $id = GETPOST('id','int');
00041 if ($user->societe_id) $socid=$user->societe_id;
00042 $result = restrictedArea($user, 'deplacement', $id,'');
00043 
00044 $action = GETPOST('action','alpha');
00045 $confirm = GETPOST('confirm','alpha');
00046 
00047 $object = new Deplacement($db);
00048 
00049 // Initialize technical object to manage hooks of thirdparties. Note that conf->hooks_modules contains array array
00050 $hookmanager->initHooks(array('tripsandexpensescard'));
00051 
00052 $permissionnote=$user->rights->deplacement->creer;  // Used by the include of actions_setnotes.inc.php
00053 
00054 
00055 /*
00056  * Actions
00057  */
00058 
00059 include DOL_DOCUMENT_ROOT.'/core/actions_setnotes.inc.php'; // Must be include, not includ_once
00060 
00061 if ($action == 'validate' && $user->rights->deplacement->creer)
00062 {
00063     $object->fetch($id);
00064     if ($object->statut == 0)
00065     {
00066         $result = $object->setStatut(1);
00067         if ($result > 0)
00068         {
00069             header("Location: " . $_SERVER["PHP_SELF"] . "?id=" . $id);
00070             exit;
00071         }
00072         else
00073         {
00074           setEventMessage($object->error, 'errors');
00075         }
00076     }
00077 }
00078 
00079 else if ($action == 'confirm_delete' && $confirm == "yes" && $user->rights->deplacement->supprimer)
00080 {
00081     $result=$object->delete($id);
00082     if ($result >= 0)
00083     {
00084         header("Location: index.php");
00085         exit;
00086     }
00087     else
00088     {
00089       setEventMessage($object->error, 'errors');
00090     }
00091 }
00092 
00093 else if ($action == 'add' && $user->rights->deplacement->creer)
00094 {
00095     if (! GETPOST('cancel','alpha'))
00096     {
00097         $error=0;
00098 
00099         $object->date     = dol_mktime(12, 0, 0, GETPOST('remonth','int'), GETPOST('reday','int'), GETPOST('reyear','int'));
00100         $object->km       = GETPOST('km','int');
00101         $object->type     = GETPOST('type','alpha');
00102         $object->socid      = GETPOST('socid','int');
00103         $object->fk_user    = GETPOST('fk_user','int');
00104         $object->note_private = GETPOST('note_private','alpha');
00105         $object->note_public  = GETPOST('note_public','alpha');
00106         $object->statut       = 0;
00107 
00108         if (! $object->date)
00109         {
00110           setEventMessage($langs->trans("ErrorFieldRequired",$langs->transnoentitiesnoconv("Date")), 'errors');
00111             $error++;
00112         }
00113         if ($object->type == '-1')  // Otherwise it is TF_LUNCH,...
00114         {
00115           setEventMessage($langs->trans("ErrorFieldRequired",$langs->transnoentitiesnoconv("Type")), 'errors');
00116             $error++;
00117         }
00118         if (! ($object->fk_user > 0))
00119         {
00120           setEventMessage($langs->trans("ErrorFieldRequired",$langs->transnoentitiesnoconv("Person")), 'errors');
00121             $error++;
00122         }
00123 
00124         if (! $error)
00125         {
00126             $id = $object->create($user);
00127 
00128             if ($id > 0)
00129             {
00130                 header("Location: " . $_SERVER["PHP_SELF"] . "?id=" . $id);
00131                 exit;
00132             }
00133             else
00134             {
00135               setEventMessage($object->error, 'errors');
00136                 $action='create';
00137             }
00138         }
00139         else
00140         {
00141             $action='create';
00142         }
00143     }
00144     else
00145     {
00146         header("Location: index.php");
00147         exit;
00148     }
00149 }
00150 
00151 // Update record
00152 else if ($action == 'update' && $user->rights->deplacement->creer)
00153 {
00154     if (! GETPOST('cancel','alpha'))
00155     {
00156         $result = $object->fetch($id);
00157 
00158         $object->date     = dol_mktime(12, 0, 0, GETPOST('remonth','int'), GETPOST('reday','int'), GETPOST('reyear','int'));
00159         $object->km       = GETPOST('km','int');
00160         $object->type     = GETPOST('type','alpha');
00161         $object->socid      = GETPOST('socid','int');
00162         $object->fk_user    = GETPOST('fk_user','int');
00163         $object->note_private = GETPOST('note_private','alpha');
00164         $object->note_public  = GETPOST('note_public','alpha');
00165 
00166         $result = $object->update($user);
00167 
00168         if ($result > 0)
00169         {
00170             header("Location: " . $_SERVER["PHP_SELF"] . "?id=" . $id);
00171             exit;
00172         }
00173         else
00174         {
00175           setEventMessage($object->error, 'errors');
00176         }
00177     }
00178     else
00179     {
00180         header("Location: " . $_SERVER["PHP_SELF"] . "?id=" . $id);
00181         exit;
00182     }
00183 }
00184 
00185 // Set into a project
00186 else if ($action == 'classin' && $user->rights->deplacement->creer)
00187 {
00188     $object->fetch($id);
00189     $result=$object->setProject(GETPOST('projectid','int'));
00190     if ($result < 0) dol_print_error($db, $object->error);
00191 }
00192 
00193 // Set fields
00194 else if ($action == 'setdated' && $user->rights->deplacement->creer)
00195 {
00196     $dated=dol_mktime(GETPOST('datedhour','int'), GETPOST('datedmin','int'), GETPOST('datedsec','int'), GETPOST('datedmonth','int'), GETPOST('datedday','int'), GETPOST('datedyear','int'));
00197     $object->fetch($id);
00198     $result=$object->setValueFrom('dated',$dated,'','','date');
00199     if ($result < 0) dol_print_error($db, $object->error);
00200 }
00201 else if ($action == 'setkm' && $user->rights->deplacement->creer)
00202 {
00203     $object->fetch($id);
00204     $result=$object->setValueFrom('km',GETPOST('km','int'));
00205     if ($result < 0) dol_print_error($db, $object->error);
00206 }
00207 
00208 
00209 /*
00210  * View
00211  */
00212 
00213 llxHeader();
00214 
00215 $form = new Form($db);
00216 
00217 /*
00218  * Action create
00219 */
00220 if ($action == 'create')
00221 {
00222     //WYSIWYG Editor
00223     require_once DOL_DOCUMENT_ROOT.'/core/class/doleditor.class.php';
00224 
00225     print_fiche_titre($langs->trans("NewTrip"));
00226 
00227     $datec = dol_mktime(12, 0, 0, GETPOST('remonth','int'), GETPOST('reday','int'), GETPOST('reyear','int'));
00228 
00229     print '<form name="add" action="' . $_SERVER["PHP_SELF"] . '" method="POST">' . "\n";
00230     print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
00231     print '<input type="hidden" name="action" value="add">';
00232 
00233     print '<table class="border" width="100%">';
00234 
00235     print "<tr>";
00236     print '<td width="25%" class="fieldrequired">'.$langs->trans("Type").'</td><td>';
00237     print $form->select_type_fees(GETPOST('type','int'),'type',1);
00238     print '</td></tr>';
00239 
00240     print "<tr>";
00241     print '<td class="fieldrequired">'.$langs->trans("Person").'</td><td>';
00242     print $form->select_dolusers(GETPOST('fk_user','int'),'fk_user',1);
00243     print '</td></tr>';
00244 
00245     print "<tr>";
00246     print '<td class="fieldrequired">'.$langs->trans("Date").'</td><td>';
00247     print $form->select_date($datec?$datec:-1,'','','','','add',1,1);
00248     print '</td></tr>';
00249 
00250     // Km
00251     print '<tr><td class="fieldrequired">'.$langs->trans("FeesKilometersOrAmout").'</td><td><input name="km" size="10" value="' . GETPOST("km") . '"></td></tr>';
00252 
00253     // Company
00254     print "<tr>";
00255     print '<td>'.$langs->trans("CompanyVisited").'</td><td>';
00256     print $form->select_company(GETPOST('socid','int'),'socid','',1);
00257     print '</td></tr>';
00258 
00259     // Public note
00260     print '<tr>';
00261     print '<td class="border" valign="top">'.$langs->trans('NotePublic').'</td>';
00262     print '<td valign="top" colspan="2">';
00263 
00264     $doleditor = new DolEditor('note_public', GETPOST('note_public', 'alpha'), '', 200, 'dolibarr_notes', 'In', false, true, true, ROWS_8, 100);
00265     print $doleditor->Create(1);
00266 
00267     print '</td></tr>';
00268 
00269     // Private note
00270     if (empty($user->societe_id))
00271     {
00272         print '<tr>';
00273         print '<td class="border" valign="top">'.$langs->trans('NotePrivate').'</td>';
00274         print '<td valign="top" colspan="2">';
00275 
00276         $doleditor = new DolEditor('note_private', GETPOST('note_private', 'alpha'), '', 200, 'dolibarr_notes', 'In', false, true, true, ROWS_8, 100);
00277         print $doleditor->Create(1);
00278 
00279         print '</td></tr>';
00280     }
00281 
00282     // Other attributes
00283     $parameters=array('colspan' => ' colspan="2"');
00284     $reshook=$hookmanager->executeHooks('formObjectOptions',$parameters,$object,$action);    // Note that $action and $object may have been modified by hook
00285 
00286     print '</table>';
00287 
00288     print '<br><center><input class="button" type="submit" value="'.$langs->trans("Save").'"> &nbsp; &nbsp; ';
00289     print '<input class="button" type="submit" name="cancel" value="'.$langs->trans("Cancel").'"></center';
00290 
00291     print '</form>';
00292 }
00293 else if ($id)
00294 {
00295     $result = $object->fetch($id);
00296     if ($result > 0)
00297     {
00298         $head = trip_prepare_head($object);
00299 
00300         dol_fiche_head($head, 'card', $langs->trans("TripCard"), 0, 'trip');
00301 
00302         if ($action == 'edit' && $user->rights->deplacement->creer)
00303         {
00304             //WYSIWYG Editor
00305             require_once DOL_DOCUMENT_ROOT.'/core/class/doleditor.class.php';
00306 
00307             $soc = new Societe($db);
00308             if ($object->socid)
00309             {
00310                 $soc->fetch($object->socid);
00311             }
00312 
00313             print '<form name="update" action="' . $_SERVER["PHP_SELF"] . '" method="POST">' . "\n";
00314             print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
00315             print '<input type="hidden" name="action" value="update">';
00316             print '<input type="hidden" name="id" value="'.$id.'">';
00317 
00318             print '<table class="border" width="100%">';
00319 
00320             // Ref
00321             print "<tr>";
00322             print '<td width="20%">'.$langs->trans("Ref").'</td><td>';
00323             print $object->ref;
00324             print '</td></tr>';
00325 
00326             // Type
00327             print "<tr>";
00328             print '<td class="fieldrequired">'.$langs->trans("Type").'</td><td>';
00329             print $form->select_type_fees(GETPOST('type','int')?GETPOST('type','int'):$object->type,'type',0);
00330             print '</td></tr>';
00331 
00332             // Who
00333             print "<tr>";
00334             print '<td class="fieldrequired">'.$langs->trans("Person").'</td><td>';
00335             print $form->select_dolusers(GETPOST('fk_user','int')?GETPOST('fk_user','int'):$object->fk_user,'fk_user',0);
00336             print '</td></tr>';
00337 
00338             // Date
00339             print '<tr><td class="fieldrequired">'.$langs->trans("Date").'</td><td>';
00340             print $form->select_date($object->date,'','','','','update');
00341             print '</td></tr>';
00342 
00343             // Km
00344             print '<tr><td class="fieldrequired">'.$langs->trans("FeesKilometersOrAmout").'</td><td>';
00345             print '<input name="km" class="flat" size="10" value="'.$object->km.'">';
00346             print '</td></tr>';
00347 
00348             // Where
00349             print "<tr>";
00350             print '<td>'.$langs->trans("CompanyVisited").'</td><td>';
00351             print $form->select_company($soc->id,'socid','',1);
00352             print '</td></tr>';
00353 
00354             // Public note
00355             print '<tr><td valign="top">'.$langs->trans("NotePublic").'</td>';
00356             print '<td valign="top" colspan="3">';
00357 
00358             $doleditor = new DolEditor('note_public', $object->note_public, '', 200, 'dolibarr_notes', 'In', false, true, true, ROWS_8, '100');
00359             print $doleditor->Create(1);
00360 
00361             print "</td></tr>";
00362 
00363             // Private note
00364             if (empty($user->societe_id))
00365             {
00366                 print '<tr><td valign="top">'.$langs->trans("NotePrivate").'</td>';
00367                 print '<td valign="top" colspan="3">';
00368 
00369                 $doleditor = new DolEditor('note_private', $object->note_private, '', 200, 'dolibarr_notes', 'In', false, true, true, ROWS_8, '100');
00370                 print $doleditor->Create(1);
00371 
00372                 print "</td></tr>";
00373             }
00374 
00375             // Other attributes
00376             $parameters=array('colspan' => ' colspan="3"');
00377             $reshook=$hookmanager->executeHooks('formObjectOptions',$parameters,$object,$action);    // Note that $action and $object may have been modified by hook
00378 
00379             print '</table>';
00380 
00381             print '<br><center><input type="submit" class="button" value="'.$langs->trans("Save").'"> &nbsp; ';
00382             print '<input type="submit" name="cancel" class="button" value="'.$langs->trans("Cancel").'">';
00383             print '</center>';
00384 
00385             print '</form>';
00386 
00387             print '</div>';
00388         }
00389         else
00390         {
00391             /*
00392              * Confirmation de la suppression du deplacement
00393             */
00394             if ($action == 'delete')
00395             {
00396                 print $form->formconfirm($_SERVER["PHP_SELF"]."?id=".$id,$langs->trans("DeleteTrip"),$langs->trans("ConfirmDeleteTrip"),"confirm_delete");
00397 
00398             }
00399 
00400             $soc = new Societe($db);
00401             if ($object->socid) $soc->fetch($object->socid);
00402 
00403             print '<table class="border" width="100%">';
00404 
00405             $linkback = '<a href="'.DOL_URL_ROOT.'/compta/deplacement/list.php'.(! empty($socid)?'?socid='.$socid:'').'">'.$langs->trans("BackToList").'</a>';
00406 
00407             // Ref
00408             print '<tr><td width="25%">'.$langs->trans("Ref").'</td><td>';
00409             print $form->showrefnav($object, 'id', $linkback, 1, 'rowid', 'ref', '');
00410             print '</td></tr>';
00411 
00412             // Type
00413             print '<tr><td>';
00414             print $form->editfieldkey("Type",'type',$langs->trans($object->type),$object,$conf->global->MAIN_EDIT_ALSO_INLINE && $user->rights->deplacement->creer,'select:types_fees');
00415             print '</td><td>';
00416             print $form->editfieldval("Type",'type',$langs->trans($object->type),$object,$conf->global->MAIN_EDIT_ALSO_INLINE && $user->rights->deplacement->creer,'select:types_fees');
00417             print '</td></tr>';
00418 
00419             // Who
00420             print '<tr><td>'.$langs->trans("Person").'</td><td>';
00421             $userfee=new User($db);
00422             $userfee->fetch($object->fk_user);
00423             print $userfee->getNomUrl(1);
00424             print '</td></tr>';
00425 
00426             // Date
00427             print '<tr><td>';
00428             print $form->editfieldkey("Date",'dated',$object->date,$object,$conf->global->MAIN_EDIT_ALSO_INLINE && $user->rights->deplacement->creer,'datepicker');
00429             print '</td><td>';
00430             print $form->editfieldval("Date",'dated',$object->date,$object,$conf->global->MAIN_EDIT_ALSO_INLINE && $user->rights->deplacement->creer,'datepicker');
00431             print '</td></tr>';
00432 
00433             // Km/Price
00434             print '<tr><td valign="top">';
00435             print $form->editfieldkey("FeesKilometersOrAmout",'km',$object->km,$object,$conf->global->MAIN_EDIT_ALSO_INLINE && $user->rights->deplacement->creer,'numeric:6');
00436             print '</td><td>';
00437             print $form->editfieldval("FeesKilometersOrAmout",'km',$object->km,$object,$conf->global->MAIN_EDIT_ALSO_INLINE && $user->rights->deplacement->creer,'numeric:6');
00438             print "</td></tr>";
00439 
00440             // Where
00441             print '<tr><td>'.$langs->trans("CompanyVisited").'</td>';
00442             print '<td>';
00443             if ($soc->id) print $soc->getNomUrl(1);
00444             print '</td></tr>';
00445 
00446             // Project
00447             if (! empty($conf->projet->enabled))
00448             {
00449                 $langs->load('projects');
00450                 print '<tr>';
00451                 print '<td>';
00452 
00453                 print '<table class="nobordernopadding" width="100%"><tr><td>';
00454                 print $langs->trans('Project');
00455                 print '</td>';
00456                 if ($action != 'classify' && $user->rights->deplacement->creer)
00457                 {
00458                     print '<td align="right"><a href="'.$_SERVER["PHP_SELF"].'?action=classify&amp;id='.$object->id.'">';
00459                     print img_edit($langs->trans('SetProject'),1);
00460                     print '</a></td>';
00461                 }
00462                 print '</tr></table>';
00463                 print '</td><td colspan="3">';
00464                 if ($action == 'classify')
00465                 {
00466                     $form->form_project($_SERVER['PHP_SELF'].'?id='.$object->id, $object->socid, $object->fk_project,'projectid');
00467                 }
00468                 else
00469                 {
00470                     $form->form_project($_SERVER['PHP_SELF'].'?id='.$object->id, $object->socid, $object->fk_project,'none');
00471                 }
00472                 print '</td>';
00473                 print '</tr>';
00474             }
00475 
00476             // Statut
00477             print '<tr><td>'.$langs->trans("Status").'</td><td>'.$object->getLibStatut(4).'</td></tr>';
00478 
00479             // Other attributes
00480             $parameters=array('colspan' => ' colspan="3"', 'showblocbydefault' => 1);
00481             $reshook=$hookmanager->executeHooks('formObjectOptions',$parameters,$object,$action);    // Note that $action and $object may have been modified by hook
00482 
00483             print "</table><br>";
00484 
00485             // Notes
00486             $blocname = 'notes';
00487             $title = $langs->trans('Notes');
00488             include DOL_DOCUMENT_ROOT.'/core/tpl/bloc_showhide.tpl.php';
00489 
00490             print '</div>';
00491 
00492             /*
00493              * Barre d'actions
00494             */
00495 
00496             print '<div class="tabsAction">';
00497 
00498             if ($object->statut == 0)   // if blocked...
00499             {
00500                 if ($user->rights->deplacement->creer)
00501                 {
00502                     print '<a class="butAction" href="'.$_SERVER["PHP_SELF"].'?action=validate&id='.$id.'">'.$langs->trans('Validate').'</a>';
00503                 }
00504                 else
00505                 {
00506                     print '<a class="butActionRefused" href="#" title="'.dol_escape_htmltag($langs->trans("NotAllowed")).'">'.$langs->trans('Validate').'</a>';
00507                 }
00508             }
00509 
00510             if ($user->rights->deplacement->creer)
00511             {
00512                 print '<a class="butAction" href="'.$_SERVER["PHP_SELF"].'?action=edit&id='.$id.'">'.$langs->trans('Modify').'</a>';
00513             }
00514             else
00515             {
00516                 print '<a class="butActionRefused" href="#" title="'.dol_escape_htmltag($langs->trans("NotAllowed")).'">'.$langs->trans('Modify').'</a>';
00517             }
00518             if ($user->rights->deplacement->supprimer)
00519             {
00520                 print '<a class="butActionDelete" href="'.$_SERVER["PHP_SELF"].'?action=delete&id='.$id.'">'.$langs->trans('Delete').'</a>';
00521             }
00522             else
00523             {
00524                 print '<a class="butActionRefused" href="#" title="'.dol_escape_htmltag($langs->trans("NotAllowed")).'">'.$langs->trans('Delete').'</a>';
00525             }
00526 
00527             print '</div>';
00528         }
00529     }
00530     else
00531     {
00532         dol_print_error($db);
00533     }
00534 }
00535 
00536 
00537 llxFooter();
00538 
00539 $db->close();

Generated on Fri Aug 1 2014 14:56:38 for dolibarr by Doxygen 1.7.6.1
